@@ -296,45 +296,6 @@ calibrate <- function(cage=2450, error=50, reservoir=0, prob=0.95, cc=1, cc1="3C
 
 
 
-#' @name mix.calibrationcurves
-#' @title Build a custom-made, mixed calibration curve. 
-#' @description If two curves need to be 'mixed' to calibrate, e.g. for dates of mixed terrestrial and marine carbon sources, then this function can be used. 
-#' @details The proportional contribution of each of both calibration curves has to be set. 
-#'
-#' @param proportion Proportion of the first calibration curve required. e.g., change to \code{proportion=0.7} if \code{cc1} should contribute 70\% (and \code{cc2} 30\%) to the mixed curve.
-#' @param cc1 The first calibration curve to be mixed. Defaults to the northern hemisphere terrestrial curve IntCal20.
-#' @param cc2 The second calibration curve to be mixed. Defaults to the marine curve Marine20.
-#' @param name Name of the new calibration curve.
-#' @param dirname Directory where the file will be written. If using the default \code{dirname="."}, 
-#' the new curve will be saved in current working directory. 
-#' @param offset Any offset and error to be applied to \code{cc2} (default 0 +- 0).
-#' @param sep Separator between fields (tab by default, "\\t") 
-#' @param rule How should R's approx function deal with extrapolation. If \code{rule=1}, the default, then NAs are returned for such points and if it is 2, the value at the closest data extreme is used.
-#' @author Maarten Blaauw, J. Andres Christen
-#' @return A file containing the custom-made calibration curve, based on calibration curves \code{cc1} and \code{cc2}.
-#' @examples
-#'   mix.calibrationcurves(dirname=tempdir())
-#' @export
-mix.calibrationcurves <- function(proportion=.5, cc1="3Col_intcal20.14C", cc2="3Col_marine20.14C", name="mixed.14C", dirname=".", offset=c(0,0), sep="\t", rule=1) {
-  ccloc <- normalizePath(system.file("extdata/", package='IntCal')) 
-  dirname <- .validateDirectoryName(dirname)
-  
-  cc1 <- read.table(normalizePath(paste(ccloc, "/", cc1,  sep="")))
-  cc2 <- read.table(normalizePath(paste(ccloc, "/", cc2,  sep="")))
-  cc2.mu <- approx(cc2[,1], cc2[,2], cc1[,1], rule=rule)$y + offset[1] # interpolate cc2 to the calendar years of cc1
-  cc2.error <- approx(cc2[,1], cc2[,3], cc1[,1], rule=rule)$y
-  cc2.error <- sqrt(cc2.error^2 + offset[2]^2)
-  mu <- proportion * cc1[,2] + (1-proportion) * cc2.mu
-  error <- proportion * cc1[,3] + (1-proportion) * cc2.error
-  write.table(cbind(cc1[,1], mu, error), paste(dirname, name,  sep="") , row.names=FALSE, col.names=FALSE, sep=sep)
-}
-
-
-
-
-
-
-
 # See Christen and Perez 2009, Radiocarbon 51:1047-1059. Instead of assuming the standard Gaussian model (default in clam), a student t distribution can be used with two parameters. Christen and Perez 2009 suggest t.a = 3 and t.b = 4; this can be put as clam( calibt=c(3,4) )
 .calibt <- function(t.a, t.b, f.cage, f.error, f.mu, f.sigma) # removed theta as par
   (t.b + ((f.cage-f.mu)^2) / (2*(f.sigma^2 + f.error^2))) ^ (-1*(t.a+0.5))
